==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/EQUIPMENTSUPPLIERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for EQUIPMENTSUPPLIERID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="EQUIPMENTSUPPLIERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTSUPPLIERPK"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EQUIPMENTSUPPLIERID_Type", propOrder = {
    "equipmentsupplierpk"
})
public class EQUIPMENTSUPPLIERID_Type {

    @XmlElement(name = "EQUIPMENTSUPPLIERPK", required = true)
    protected String equipmentsupplierpk;

    /**
     * Gets the value of the equipmentsupplierpk property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEQUIPMENTSUPPLIERPK() {
        return equipmentsupplierpk;
    }

    /**
     * Sets the value of the equipmentsupplierpk property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEQUIPMENTSUPPLIERPK(String value) {
        this.equipmentsupplierpk = value;
    }

}

==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/EQUIPMENTSUPPLIERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour EQUIPMENTSUPPLIERID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EQUIPMENTSUPPLIERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTSUPPLIERPK"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EQUIPMENTSUPPLIERID_Type", propOrder = {
    "equipmentsupplierpk"
})
public class EQUIPMENTSUPPLIERID_Type {

    @XmlElement(name = "EQUIPMENTSUPPLIERPK", required = true)
    protected String equipmentsupplierpk;

    /**
     * Obtient la valeur de la propriété equipmentsupplierpk.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEQUIPMENTSUPPLIERPK() {
        return equipmentsupplierpk;
    }

    /**
     * Définit la valeur de la propriété equipmentsupplierpk.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEQUIPMENTSUPPLIERPK(String value) {
        this.equipmentsupplierpk = value;
    }

}
